@@ -7,7 +7,9 @@ DataPress API client and utilities.
 from .__version__ import __version__ as version
 print('Loading datapress_client version: ' + version)
 
-from .geo import *
-from .extract import *
-from .nomis import *
-from .script import *
+from .dataset import get_dataset
+from . import geo
+from . import extract
+from . import nomis
+from . import api
+from . import dataset
